@@ -25,9 +25,6 @@
 
 #include "gsm-systemd.h"
 
-#ifdef HAVE_CONSOLEKIT
-#include "gsm-consolekit.h"
-#endif
 
 enum {
         REQUEST_COMPLETED,
@@ -270,15 +267,6 @@ gsm_get_system (void)
                 }
         }
 
-#ifdef HAVE_CONSOLEKIT
-        if (system == NULL) {
-                system = GSM_SYSTEM (gsm_consolekit_new ());
-                if (system != NULL) {
-                        g_debug ("Using ConsoleKit for session tracking");
-                }
-        }
-#endif
-
         if (system == NULL) {
                 system = g_object_new (gsm_system_null_get_type (), NULL);
                 g_warning ("Using null backend for session tracking");
