@@ -8,8 +8,8 @@
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
@@ -53,7 +53,6 @@ const char * const * gsm_util_listenv               (void);
 const char * const * gsm_util_get_variable_blacklist(void);
 
 gboolean    gsm_util_export_activation_environment  (GError     **error);
-#ifdef HAVE_SYSTEMD
 gboolean    gsm_util_export_user_environment        (GError     **error);
 gboolean    gsm_util_systemd_unit_is_active         (const char  *unit,
                                                      GError     **error);
@@ -62,7 +61,6 @@ gboolean    gsm_util_start_systemd_unit             (const char  *unit,
                                                      GError     **error);
 gboolean    gsm_util_systemd_reset_failed           (GError     **error);
 
-#endif
 
 void        gsm_quit                                (void);
 
